@@ -1,9 +1,19 @@
 from sql_error_categorizer.detectors import Detector
-from sql_error_categorizer import load_catalog, SyntaxErrorDetector, SemanticErrorDetector, LogicalErrorDetector, ComplicationDetector
+from sql_error_categorizer import load_catalog, build_catalog, SyntaxErrorDetector, SemanticErrorDetector, LogicalErrorDetector, ComplicationDetector
 
-def t(query_file: str = 'q_q.sql',
-      solution_file: str = 'q_s.sql',
-      catalog_file: str = 'tests/datasets/cat_miedema.json',
+def make_catalog(file: str) -> None:
+    '''Utility function to build a catalog from a source file'''
+
+    with open(f'datasets/sql/{file}.sql') as f:
+        content = f.read()
+
+    cat = build_catalog(content, hostname='localhost', port=5432, user='postgres', password='password', schema=file, create_temp_schema=True)
+
+    cat.save_json(f'datasets/catalogs/{file}.json')
+
+def t(query_file: str = 'test_q.sql',
+      solution_file: str = 'test_s1.sql',
+      catalog_file: str = 'miedema',
       search_path: str | None = None) -> Detector:
     '''Test function, remove before production'''
 
@@ -12,7 +22,7 @@ def t(query_file: str = 'q_q.sql',
     with open(solution_file) as f:
         solution = f.read()
 
-    cat = load_catalog(catalog_file)
+    cat = load_catalog(f'datasets/catalogs/{catalog_file}.json')
 
     if search_path is None:
         search_path = cat.schema_names.pop() or 'public'
@@ -24,5 +34,3 @@ def t(query_file: str = 'q_q.sql',
     det.add_detector(ComplicationDetector)
 
     return det
-
-det = t()
